Learn R Programming

veesa (version 0.1.7)

center_warping_funs: Center warping functions

Description

The function 'prep_training_data' does not center the warping functions. For visualizing the aligned and warping functions, it can be easier to look at centered versions. This function centers the warping functions and corresponding aligned functions.

Usage

center_warping_funs(train_obj)

Value

Object with the same structure as `train_obj` but qn, fn, and gam have been replaced by centered versions

Arguments

train_obj

Output object from `prep_training_data`