The function 'prep_training_data' does not center the warping functions, which leads to issues when visualizing joint and horizontal principal component directions. This function aligns the principal directions for improved interpretability of the principal directions. Currently, only alignment for jfPCA has been implemented.
The function 'prep_training_data' does not center the warping functions, which leads to issues when visualizing joint and horizontal principal component directions. This function aligns the principal directions for improved interpretability of the principal directions. Currently, only alignment for jfPCA has been implemented.
align_pcdirs(train_obj)align_pcdirs(train_obj)
List with the same structure as `prep_training_data`, but the principal directions are replaced with the aligned version and gamI is included in the fpca_res object.
List with the same structure as `prep_training_data`, but the principal directions are replaced with the aligned version and gamI is included in the fpca_res object.
Output object from `prep_training_data` (jfpca only)