Learn R Programming

veesa (version 0.1.7)

shifted_peaks: "Shifted Peaks" Simulated Dataset

Description

A simulated dataset generated for examples in the veesa pipeline manuscript. For the code used to prepare this dataset, see https://github.com/sandialabs/veesa/inst/data-shifted-peaks.md.

Usage

shifted_peaks

Arguments

Format

A list.

Details

The objects in the list are:

dataData frame containing simulated data
paramsThe parameters used to generate the data
true_meansThe true functional means of the shifted peaks groups.